# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Optional
from pydantic import BaseModel, Field, conlist
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.default_nomination_mtu import DefaultNominationMtu

class CreateDefaultNominationRequest(BaseModel):
    """
    CreateDefaultNominationRequest
    """
    timescale: AuctionTimescale = Field(...)
    border_direction: BorderDirection = Field(..., alias="borderDirection")
    delivery_period_start: date = Field(..., alias="deliveryPeriodStart", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    delivery_period_end: Optional[date] = Field(None, alias="deliveryPeriodEnd", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    mtus: conlist(DefaultNominationMtu) = Field(...)
    __properties = ["timescale", "borderDirection", "deliveryPeriodStart", "deliveryPeriodEnd", "mtus"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateDefaultNominationRequest:
        """Create an instance of CreateDefaultNominationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateDefaultNominationRequest:
        """Create an instance of CreateDefaultNominationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateDefaultNominationRequest.parse_obj(obj)

        _obj = CreateDefaultNominationRequest.parse_obj({
            "timescale": obj.get("timescale"),
            "border_direction": obj.get("borderDirection"),
            "delivery_period_start": obj.get("deliveryPeriodStart"),
            "delivery_period_end": obj.get("deliveryPeriodEnd"),
            "mtus": [DefaultNominationMtu.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.transmission_right_api import TransmissionRightApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestTransmissionRightApi(unittest.TestCase):
    """TransmissionRightApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.transmission_right_api.TransmissionRightApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_transmission_rights_overview(self):
        """Test case for get_transmission_rights_overview

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, conint, conlist
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.buy_now_offer_mtus_inner import BuyNowOfferMtusInner
from empire_platform_api_public_client.models.buy_now_offer_status import BuyNowOfferStatus
from empire_platform_api_public_client.models.date_time_period import DateTimePeriod
from empire_platform_api_public_client.models.mtu_size import MtuSize
from empire_platform_api_public_client.models.purchased_by_organisation import PurchasedByOrganisation

class BuyNowOffer(BaseModel):
    """
    BuyNowOffer
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    validity_period: DateTimePeriod = Field(..., alias="validityPeriod")
    current_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="currentPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    next_price_change_at: datetime = Field(..., alias="nextPriceChangeAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    direction: BorderDirection = Field(...)
    status: BuyNowOfferStatus = Field(...)
    total_trs: StrictInt = Field(..., alias="totalTrs", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    total_cost: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="totalCost", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    purchased_by: Optional[PurchasedByOrganisation] = Field(None, alias="purchasedBy")
    mtu_size: MtuSize = Field(..., alias="mtuSize")
    mtus: conlist(BuyNowOfferMtusInner) = Field(...)
    __properties = ["id", "validityPeriod", "currentPrice", "nextPriceChangeAt", "direction", "status", "totalTrs", "totalCost", "purchasedBy", "mtuSize", "mtus"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BuyNowOffer:
        """Create an instance of BuyNowOffer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of validity_period
        if self.validity_period:
            _dict['validityPeriod'] = self.validity_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of purchased_by
        if self.purchased_by:
            _dict['purchasedBy'] = self.purchased_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BuyNowOffer:
        """Create an instance of BuyNowOffer from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BuyNowOffer.parse_obj(obj)

        _obj = BuyNowOffer.parse_obj({
            "id": obj.get("id"),
            "validity_period": DateTimePeriod.from_dict(obj.get("validityPeriod")) if obj.get("validityPeriod") is not None else None,
            "current_price": obj.get("currentPrice"),
            "next_price_change_at": obj.get("nextPriceChangeAt"),
            "direction": obj.get("direction"),
            "status": obj.get("status"),
            "total_trs": obj.get("totalTrs"),
            "total_cost": obj.get("totalCost"),
            "purchased_by": PurchasedByOrganisation.from_dict(obj.get("purchasedBy")) if obj.get("purchasedBy") is not None else None,
            "mtu_size": obj.get("mtuSize"),
            "mtus": [BuyNowOfferMtusInner.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import datetime

from pydantic import Field, StrictBool, StrictStr, conint, conlist

from typing import Optional

from empire_platform_api_public_client.models.message_batch import MessageBatch
from empire_platform_api_public_client.models.message_sender import MessageSender
from empire_platform_api_public_client.models.message_severity import MessageSeverity
from empire_platform_api_public_client.models.message_sort_by import MessageSortBy
from empire_platform_api_public_client.models.message_type import MessageType
from empire_platform_api_public_client.models.system_message_category import SystemMessageCategory
from empire_platform_api_public_client.models.unread_messages_response import UnreadMessagesResponse

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MessagesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_participant_messages(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[MessageSortBy, Field(..., description="Sort list by given attribute and direction")], severities : conlist(MessageSeverity), senders : conlist(MessageSender), types : conlist(MessageType), received_from : Optional[datetime] = None, received_to : Optional[datetime] = None, search_query : Optional[StrictStr] = None, has_attachment : Optional[StrictBool] = None, **kwargs) -> MessageBatch:  # noqa: E501
        """get_participant_messages  # noqa: E501

        Fetch Messages sent for the current Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_PARTICIPANT_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_participant_messages(limit, offset, sort_by, severities, senders, types, received_from, received_to, search_query, has_attachment, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: MessageSortBy
        :param severities: (required)
        :type severities: List[MessageSeverity]
        :param senders: (required)
        :type senders: List[MessageSender]
        :param types: (required)
        :type types: List[MessageType]
        :param received_from:
        :type received_from: datetime
        :param received_to:
        :type received_to: datetime
        :param search_query:
        :type search_query: str
        :param has_attachment:
        :type has_attachment: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MessageBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_participant_messages_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_participant_messages_with_http_info(limit, offset, sort_by, severities, senders, types, received_from, received_to, search_query, has_attachment, **kwargs)  # noqa: E501

    @validate_arguments
    def get_participant_messages_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[MessageSortBy, Field(..., description="Sort list by given attribute and direction")], severities : conlist(MessageSeverity), senders : conlist(MessageSender), types : conlist(MessageType), received_from : Optional[datetime] = None, received_to : Optional[datetime] = None, search_query : Optional[StrictStr] = None, has_attachment : Optional[StrictBool] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_participant_messages  # noqa: E501

        Fetch Messages sent for the current Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_PARTICIPANT_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_participant_messages_with_http_info(limit, offset, sort_by, severities, senders, types, received_from, received_to, search_query, has_attachment, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: MessageSortBy
        :param severities: (required)
        :type severities: List[MessageSeverity]
        :param senders: (required)
        :type senders: List[MessageSender]
        :param types: (required)
        :type types: List[MessageType]
        :param received_from:
        :type received_from: datetime
        :param received_to:
        :type received_to: datetime
        :param search_query:
        :type search_query: str
        :param has_attachment:
        :type has_attachment: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MessageBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'severities',
            'senders',
            'types',
            'received_from',
            'received_to',
            'search_query',
            'has_attachment'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_participant_messages" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('severities') is not None:  # noqa: E501
            _query_params.append(('severities', _params['severities']))
            _collection_formats['severities'] = 'multi'

        if _params.get('senders') is not None:  # noqa: E501
            _query_params.append(('senders', _params['senders']))
            _collection_formats['senders'] = 'multi'

        if _params.get('types') is not None:  # noqa: E501
            _query_params.append(('types', _params['types']))
            _collection_formats['types'] = 'multi'

        if _params.get('received_from') is not None:  # noqa: E501
            if isinstance(_params['received_from'], datetime):
                _query_params.append(('receivedFrom', _params['received_from'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('receivedFrom', _params['received_from']))

        if _params.get('received_to') is not None:  # noqa: E501
            if isinstance(_params['received_to'], datetime):
                _query_params.append(('receivedTo', _params['received_to'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('receivedTo', _params['received_to']))

        if _params.get('search_query') is not None:  # noqa: E501
            _query_params.append(('searchQuery', _params['search_query']))

        if _params.get('has_attachment') is not None:  # noqa: E501
            _query_params.append(('hasAttachment', _params['has_attachment']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "MessageBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/messages/participant', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_participant_unread_messages(self, **kwargs) -> UnreadMessagesResponse:  # noqa: E501
        """get_participant_unread_messages  # noqa: E501

        Fetch the number of \"unread\" Messages sent for the current Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_PARTICIPANT_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_participant_unread_messages(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UnreadMessagesResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_participant_unread_messages_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_participant_unread_messages_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_participant_unread_messages_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """get_participant_unread_messages  # noqa: E501

        Fetch the number of \"unread\" Messages sent for the current Participant  ---  __Requires Permission:__ (at least one)   * `VIEW_PARTICIPANT_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_participant_unread_messages_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UnreadMessagesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_participant_unread_messages" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "UnreadMessagesResponse",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/messages/participant/unread', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_system_messages(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[MessageSortBy, Field(..., description="Sort list by given attribute and direction")], category : SystemMessageCategory, severities : conlist(MessageSeverity), senders : conlist(MessageSender), types : conlist(MessageType), received_from : Optional[datetime] = None, received_to : Optional[datetime] = None, search_query : Optional[StrictStr] = None, has_attachment : Optional[StrictBool] = None, **kwargs) -> MessageBatch:  # noqa: E501
        """get_system_messages  # noqa: E501

        Fetch General and Operational System Messages  ---  __Requires Permission:__ (at least one)   * `VIEW_GENERAL_SYSTEM_MESSAGES`   * `VIEW_OPERATIONAL_SYSTEM_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_system_messages(limit, offset, sort_by, category, severities, senders, types, received_from, received_to, search_query, has_attachment, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: MessageSortBy
        :param category: (required)
        :type category: SystemMessageCategory
        :param severities: (required)
        :type severities: List[MessageSeverity]
        :param senders: (required)
        :type senders: List[MessageSender]
        :param types: (required)
        :type types: List[MessageType]
        :param received_from:
        :type received_from: datetime
        :param received_to:
        :type received_to: datetime
        :param search_query:
        :type search_query: str
        :param has_attachment:
        :type has_attachment: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MessageBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_system_messages_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_system_messages_with_http_info(limit, offset, sort_by, category, severities, senders, types, received_from, received_to, search_query, has_attachment, **kwargs)  # noqa: E501

    @validate_arguments
    def get_system_messages_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[MessageSortBy, Field(..., description="Sort list by given attribute and direction")], category : SystemMessageCategory, severities : conlist(MessageSeverity), senders : conlist(MessageSender), types : conlist(MessageType), received_from : Optional[datetime] = None, received_to : Optional[datetime] = None, search_query : Optional[StrictStr] = None, has_attachment : Optional[StrictBool] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_system_messages  # noqa: E501

        Fetch General and Operational System Messages  ---  __Requires Permission:__ (at least one)   * `VIEW_GENERAL_SYSTEM_MESSAGES`   * `VIEW_OPERATIONAL_SYSTEM_MESSAGES`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_system_messages_with_http_info(limit, offset, sort_by, category, severities, senders, types, received_from, received_to, search_query, has_attachment, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: MessageSortBy
        :param category: (required)
        :type category: SystemMessageCategory
        :param severities: (required)
        :type severities: List[MessageSeverity]
        :param senders: (required)
        :type senders: List[MessageSender]
        :param types: (required)
        :type types: List[MessageType]
        :param received_from:
        :type received_from: datetime
        :param received_to:
        :type received_to: datetime
        :param search_query:
        :type search_query: str
        :param has_attachment:
        :type has_attachment: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MessageBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'category',
            'severities',
            'senders',
            'types',
            'received_from',
            'received_to',
            'search_query',
            'has_attachment'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_messages" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('category') is not None:  # noqa: E501
            _query_params.append(('category', _params['category'].value))

        if _params.get('severities') is not None:  # noqa: E501
            _query_params.append(('severities', _params['severities']))
            _collection_formats['severities'] = 'multi'

        if _params.get('senders') is not None:  # noqa: E501
            _query_params.append(('senders', _params['senders']))
            _collection_formats['senders'] = 'multi'

        if _params.get('types') is not None:  # noqa: E501
            _query_params.append(('types', _params['types']))
            _collection_formats['types'] = 'multi'

        if _params.get('received_from') is not None:  # noqa: E501
            if isinstance(_params['received_from'], datetime):
                _query_params.append(('receivedFrom', _params['received_from'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('receivedFrom', _params['received_from']))

        if _params.get('received_to') is not None:  # noqa: E501
            if isinstance(_params['received_to'], datetime):
                _query_params.append(('receivedTo', _params['received_to'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('receivedTo', _params['received_to']))

        if _params.get('search_query') is not None:  # noqa: E501
            _query_params.append(('searchQuery', _params['search_query']))

        if _params.get('has_attachment') is not None:  # noqa: E501
            _query_params.append(('hasAttachment', _params['has_attachment']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "MessageBatch",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/messages/system', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr, validator
from empire_platform_api_public_client.models.profile_user_organisation import ProfileUserOrganisation

class ProfileDetails(BaseModel):
    """
    ProfileDetails
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    email: constr(strict=True) = Field(...)
    organisation: ProfileUserOrganisation = Field(...)
    name: StrictStr = Field(...)
    phone_number: constr(strict=True) = Field(..., alias="phoneNumber")
    job_title: Optional[StrictStr] = Field(None, alias="jobTitle")
    __properties = ["id", "email", "organisation", "name", "phoneNumber", "jobTitle"]

    # @validator('email')
    def email_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$", value):
            raise ValueError(r"must validate the regular expression /^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$/")
        return value

    # @validator('phone_number')
    def phone_number_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^\+\d{10,13}$", value):
            raise ValueError(r"must validate the regular expression /^\+\d{10,13}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProfileDetails:
        """Create an instance of ProfileDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of organisation
        if self.organisation:
            _dict['organisation'] = self.organisation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProfileDetails:
        """Create an instance of ProfileDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ProfileDetails.parse_obj(obj)

        _obj = ProfileDetails.parse_obj({
            "id": obj.get("id"),
            "email": obj.get("email"),
            "organisation": ProfileUserOrganisation.from_dict(obj.get("organisation")) if obj.get("organisation") is not None else None,
            "name": obj.get("name"),
            "phone_number": obj.get("phoneNumber"),
            "job_title": obj.get("jobTitle")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import StrictBytes, StrictStr

from typing import Union

from empire_platform_api_public_client.models.attachment import Attachment

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AttachmentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def upload_attachment(self, file_name : StrictStr, file : Union[StrictBytes, StrictStr], **kwargs) -> Attachment:  # noqa: E501
        """upload_attachment  # noqa: E501

        Upload a single Attachment (file)  On successful upload the file gets persisted and metadata for the Attachment is returned. The Attachment can be referenced by its identifier in other functions (e.g Organisation Documents)  **File size limit:** 50 MB  **File types accepted:**   * images:     - .jpg  | image/jpeg     - .png  | image/png   * documents:     - .doc  | application/msword     - .docx | application/vnd.openxmlformats-officedocument.wordprocessingml.document     - .xls  | application/vnd.ms-excel     - .xlsx | application/vnd.openxmlformats-officedocument.spreadsheetml.sheet     - .ppt  | application/vnd.ms-powerpoint     - .pptx | application/vnd.openxmlformats-officedocument.presentationml.presentation     - .pdf  | application/pdf   * text files:     - .txt  | text/plain     - .xml  | application/xml     - .json | application/json   * archives:     - .zip  | application/zip     - .rar  | application/vnd.rar  ---  __Requires Permission:__ (at least one)   * `MANAGE_CRISIS_ACTIONS`   * `INVITE_USERS`   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `UPLOAD_ATTACHMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_attachment(file_name, file, async_req=True)
        >>> result = thread.get()

        :param file_name: (required)
        :type file_name: str
        :param file: (required)
        :type file: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Attachment
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the upload_attachment_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.upload_attachment_with_http_info(file_name, file, **kwargs)  # noqa: E501

    @validate_arguments
    def upload_attachment_with_http_info(self, file_name : StrictStr, file : Union[StrictBytes, StrictStr], **kwargs) -> ApiResponse:  # noqa: E501
        """upload_attachment  # noqa: E501

        Upload a single Attachment (file)  On successful upload the file gets persisted and metadata for the Attachment is returned. The Attachment can be referenced by its identifier in other functions (e.g Organisation Documents)  **File size limit:** 50 MB  **File types accepted:**   * images:     - .jpg  | image/jpeg     - .png  | image/png   * documents:     - .doc  | application/msword     - .docx | application/vnd.openxmlformats-officedocument.wordprocessingml.document     - .xls  | application/vnd.ms-excel     - .xlsx | application/vnd.openxmlformats-officedocument.spreadsheetml.sheet     - .ppt  | application/vnd.ms-powerpoint     - .pptx | application/vnd.openxmlformats-officedocument.presentationml.presentation     - .pdf  | application/pdf   * text files:     - .txt  | text/plain     - .xml  | application/xml     - .json | application/json   * archives:     - .zip  | application/zip     - .rar  | application/vnd.rar  ---  __Requires Permission:__ (at least one)   * `MANAGE_CRISIS_ACTIONS`   * `INVITE_USERS`   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS`   * `MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS`   * `MANAGE_ANY_MANUAL_FILE_UPLOAD`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `UPLOAD_ATTACHMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.upload_attachment_with_http_info(file_name, file, async_req=True)
        >>> result = thread.get()

        :param file_name: (required)
        :type file_name: str
        :param file: (required)
        :type file: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Attachment, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'file_name',
            'file'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_attachment" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['file_name']:
            _form_params.append(('fileName', _params['file_name']))

        if _params['file']:
            _files['file'] = _params['file']

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '201': "Attachment",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '413': None,
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/attachments', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.date_period import DatePeriod
from empire_platform_api_public_client.models.other_party import OtherParty
from empire_platform_api_public_client.models.secondary_market_transfer_request_status import SecondaryMarketTransferRequestStatus

class SecondaryMarketTransferRequest(BaseModel):
    """
    SecondaryMarketTransferRequest
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    timescale: AuctionTimescale = Field(...)
    delivery_period: DatePeriod = Field(..., alias="deliveryPeriod")
    direction: BorderDirection = Field(...)
    transferred_capacity: StrictInt = Field(..., alias="transferredCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    requested_at: datetime = Field(..., alias="requestedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    updated_at: datetime = Field(..., alias="updatedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    completed_at: Optional[datetime] = Field(None, alias="completedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    expires_at: datetime = Field(..., alias="expiresAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    sender: OtherParty = Field(...)
    receiver: OtherParty = Field(...)
    status: SecondaryMarketTransferRequestStatus = Field(...)
    __properties = ["id", "timescale", "deliveryPeriod", "direction", "transferredCapacity", "requestedAt", "updatedAt", "completedAt", "expiresAt", "sender", "receiver", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SecondaryMarketTransferRequest:
        """Create an instance of SecondaryMarketTransferRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of delivery_period
        if self.delivery_period:
            _dict['deliveryPeriod'] = self.delivery_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of sender
        if self.sender:
            _dict['sender'] = self.sender.to_dict()
        # override the default output from pydantic by calling `to_dict()` of receiver
        if self.receiver:
            _dict['receiver'] = self.receiver.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SecondaryMarketTransferRequest:
        """Create an instance of SecondaryMarketTransferRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SecondaryMarketTransferRequest.parse_obj(obj)

        _obj = SecondaryMarketTransferRequest.parse_obj({
            "id": obj.get("id"),
            "timescale": obj.get("timescale"),
            "delivery_period": DatePeriod.from_dict(obj.get("deliveryPeriod")) if obj.get("deliveryPeriod") is not None else None,
            "direction": obj.get("direction"),
            "transferred_capacity": obj.get("transferredCapacity"),
            "requested_at": obj.get("requestedAt"),
            "updated_at": obj.get("updatedAt"),
            "completed_at": obj.get("completedAt"),
            "expires_at": obj.get("expiresAt"),
            "sender": OtherParty.from_dict(obj.get("sender")) if obj.get("sender") is not None else None,
            "receiver": OtherParty.from_dict(obj.get("receiver")) if obj.get("receiver") is not None else None,
            "status": obj.get("status")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.bidding_configuration_per_direction import BiddingConfigurationPerDirection  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestBiddingConfigurationPerDirection(unittest.TestCase):
    """BiddingConfigurationPerDirection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test BiddingConfigurationPerDirection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BiddingConfigurationPerDirection`
        """
        model = empire_platform_api_public_client.models.bidding_configuration_per_direction.BiddingConfigurationPerDirection()  # noqa: E501
        if include_optional :
            return BiddingConfigurationPerDirection(
                maximum_bid_capacity = 56, 
                warning_bid_price = 1.337, 
                maximum_bid_price = 1.337
            )
        else :
            return BiddingConfigurationPerDirection(
        )
        """

    def testBiddingConfigurationPerDirection(self):
        """Test BiddingConfigurationPerDirection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from empire_platform_api_public_client.models.dashboard_next_nomination_gate import DashboardNextNominationGate
from empire_platform_api_public_client.models.participant_dashboard_next_auction import ParticipantDashboardNextAuction

class ParticipantDashboardNextAuctionsAndNominationGates(BaseModel):
    """
    ParticipantDashboardNextAuctionsAndNominationGates
    """
    nomination_gates: conlist(DashboardNextNominationGate) = Field(..., alias="nominationGates")
    day_ahead_auctions: conlist(ParticipantDashboardNextAuction) = Field(..., alias="dayAheadAuctions")
    intra_day_auctions: conlist(ParticipantDashboardNextAuction) = Field(..., alias="intraDayAuctions")
    __properties = ["nominationGates", "dayAheadAuctions", "intraDayAuctions"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardNextAuctionsAndNominationGates:
        """Create an instance of ParticipantDashboardNextAuctionsAndNominationGates from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in nomination_gates (list)
        _items = []
        if self.nomination_gates:
            for _item in self.nomination_gates:
                if _item:
                    _items.append(_item.to_dict())
            _dict['nominationGates'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in day_ahead_auctions (list)
        _items = []
        if self.day_ahead_auctions:
            for _item in self.day_ahead_auctions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['dayAheadAuctions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in intra_day_auctions (list)
        _items = []
        if self.intra_day_auctions:
            for _item in self.intra_day_auctions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['intraDayAuctions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardNextAuctionsAndNominationGates:
        """Create an instance of ParticipantDashboardNextAuctionsAndNominationGates from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardNextAuctionsAndNominationGates.parse_obj(obj)

        _obj = ParticipantDashboardNextAuctionsAndNominationGates.parse_obj({
            "nomination_gates": [DashboardNextNominationGate.from_dict(_item) for _item in obj.get("nominationGates")] if obj.get("nominationGates") is not None else None,
            "day_ahead_auctions": [ParticipantDashboardNextAuction.from_dict(_item) for _item in obj.get("dayAheadAuctions")] if obj.get("dayAheadAuctions") is not None else None,
            "intra_day_auctions": [ParticipantDashboardNextAuction.from_dict(_item) for _item in obj.get("intraDayAuctions")] if obj.get("intraDayAuctions") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_return_request import SecondaryMarketReturnRequest  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketReturnRequest(unittest.TestCase):
    """SecondaryMarketReturnRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketReturnRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketReturnRequest`
        """
        model = empire_platform_api_public_client.models.secondary_market_return_request.SecondaryMarketReturnRequest()  # noqa: E501
        if include_optional :
            return SecondaryMarketReturnRequest(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                source_auction = empire_platform_api_public_client.models.source_auction_display_data.SourceAuctionDisplayData(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', ), 
                return_auction = empire_platform_api_public_client.models.return_auction.ReturnAuction(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                    direction = 'GB_NL', 
                    delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                        from_mtu_start = '2022-01-04T10:00Z', 
                        to_mtu_end = '2022-01-04T11:00Z', ), 
                    status = 'CREATED', ), 
                returned_capacity = 56, 
                successfully_allocated_capacity = 56, 
                price = 1.337, 
                status = 'PENDING'
            )
        else :
            return SecondaryMarketReturnRequest(
                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09',
                source_auction = empire_platform_api_public_client.models.source_auction_display_data.SourceAuctionDisplayData(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', ),
                return_auction = empire_platform_api_public_client.models.return_auction.ReturnAuction(
                    id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                    display_id = 'BDL-NL-GB-E-BASE---220305-01', 
                    direction = 'GB_NL', 
                    delivery_period = empire_platform_api_public_client.models.mtu_period.MtuPeriod(
                        from_mtu_start = '2022-01-04T10:00Z', 
                        to_mtu_end = '2022-01-04T11:00Z', ), 
                    status = 'CREATED', ),
                returned_capacity = 56,
                status = 'PENDING',
        )
        """

    def testSecondaryMarketReturnRequest(self):
        """Test SecondaryMarketReturnRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from empire_platform_api_public_client.models.auction_result_participant import AuctionResultParticipant

class LongTermAuctionResultsAllocatedCapacityInner(BaseModel):
    """
    * `requestedCapacity` - Sum of ALL bids from the given Participant in kilowatts * `allocatedTrs` - Transmission rights allocated for the given Participant in the Auction 
    """
    participant: AuctionResultParticipant = Field(...)
    requested_capacity: Optional[StrictInt] = Field(None, alias="requestedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    allocated_trs: StrictInt = Field(..., alias="allocatedTrs", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    __properties = ["participant", "requestedCapacity", "allocatedTrs"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LongTermAuctionResultsAllocatedCapacityInner:
        """Create an instance of LongTermAuctionResultsAllocatedCapacityInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of participant
        if self.participant:
            _dict['participant'] = self.participant.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LongTermAuctionResultsAllocatedCapacityInner:
        """Create an instance of LongTermAuctionResultsAllocatedCapacityInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LongTermAuctionResultsAllocatedCapacityInner.parse_obj(obj)

        _obj = LongTermAuctionResultsAllocatedCapacityInner.parse_obj({
            "participant": AuctionResultParticipant.from_dict(obj.get("participant")) if obj.get("participant") is not None else None,
            "requested_capacity": obj.get("requestedCapacity"),
            "allocated_trs": obj.get("allocatedTrs")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry import SecondaryMarketDayAheadOrIntraDayNoticeboardEntry  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(unittest.TestCase):
    """SecondaryMarketDayAheadOrIntraDayNoticeboardEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketDayAheadOrIntraDayNoticeboardEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketDayAheadOrIntraDayNoticeboardEntry`
        """
        model = empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry.SecondaryMarketDayAheadOrIntraDayNoticeboardEntry()  # noqa: E501
        if include_optional :
            return SecondaryMarketDayAheadOrIntraDayNoticeboardEntry(
                notice_details = empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_details.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryDetails(
                    type = 'BUY', 
                    timescale = 'LONG_TERM', 
                    mtu_size = 'MTU_15_MINS', 
                    delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                    direction = 'GB_NL', 
                    expires_at = '2022-01-04T00:00Z', 
                    mtus = [
                        empire_platform_api_public_client.models.secondary_market_capacity_price_mtu.SecondaryMarketCapacityPriceMtu(
                            mtu = '2022-01-04T10:00Z', 
                            capacity = 56, 
                            price = 1.337, )
                        ], 
                    is_own = True, ), 
                responses = [
                    empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse(
                        mtus = [
                            empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response_mtus_inner.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse_mtus_inner(
                                mtu = '2022-01-04T10:00Z', 
                                response_capacity = 56, 
                                response_price = 1.337, )
                            ], 
                        contact_name = '', 
                        phone_number = '+480728880015', 
                        email = '2@MDTMv2D2ylmgd10Z3UB6UkJSISSB512iz2DiJykO4IVP7YNsKQHh9BsaMPOiOuo3_QLOpkB.KIPOf2Flbsh1TpRS00PDvgoKGNXgxLHoPJE._eVrdJNcY9CLxYxBbcfSJXXZGSCF7dC-lSY-7ZlQJLW1_GNchKk5EBLDz1ctzsIY4oI.cl12VtuaSfjvmymTJfYkic17VJpcq1X6tjkH36lFYtIUw23vATP5cgpgctxW3q4fsZS5Uz-fvg2bA4.I-r1orbd3s4Kdu4Q19mfvL0A7Rpn3Av26g7OJWsQ0WBkWv3CuuRrMkJf5gzLvv2wY.NPqhvoybcy8QU.0_1u6BhIo-27B5JIFoxlv9-BJxhRRelW6lINX6.1Elv8Z4qYvYNwb3t4awGG-6yh0-gMEzQ8uhi90kNEaHx.5LWBoOt62fDnfouEM59JJWYHa1Ya1DpwFCTpIA0Gnqa9PQ0lvjCR3UYpt1vrS1p.R1OzxrQfgrgcyvfHmHL7bSaRv9kZ_K.NGkIi19s7KrTBx8qCkWG3nkJgXYUf-2g1bLoF4Q2SDvsQvki_Gv.3xSglBiD_kTqWft7LgtQq8DkTxH9-GEgnhdskTUa-JGB99tBTH1m8LyVjqKCRWp6XS1rwkzrnn.h0XoK7cYVKPWx4kXAhG_GEdV9fi1LUY2eBXIK-aaNx-IAoUxtYKQpsS2HM0cvxv.88aJmQRbOi5pM9K4SWNKj0UeVyhnBjVWguY2vNQIw3D_aRMF2Tm7SelZBdyPOLRs2IImu0zJ-sEvqrLoPmgi.JrQNmT_4QLVs0oSHjB6pC-1mwGXNIZ-mK8w9K1xfp9OikxJ6eiOUAchnVGrwqvIGWHJ7Z1.eTeQr7h2GhDiufc8pTDOUcgYQwyEct13aGy9ShDDH49uy_cuS1qDT5br69Zb9J7ztaciXoL3UMxQsS4RhgPVNkMuBNIrWv_v.6kENTnbd0jYevK4Igno2LdfSDI1Cs6huybGb1zEpVJcz_sYPOWoI5540Y2OLcYufJVmh2PNuin04QumvvjetJ2wYXn.2W6zwIrDKlbs9CPExuzXJjOmov9hu5QjJ_xMDMiy-rwLYYugfVA0tbOL0.zdgU9sGpVxk.V0XsgBCaMb6w.WmQk2AHCmB9lVwewmjj04um-gQsMcYoZx6RzkDL1MAzcQRnYq9jshsHLjup_Xq1.S5JIFlA8s7VLbfJ8CdU1--K_bbEzgXW.tGc11HJjfPh9aPBMPn9vOOHdKkQ6_InnGXC1663IOeomDvz9sa4XpvFxFUjA2Vr.PYqBpPgKYJXJXx50oGq47BDC1bkGeAny7jvr.nVoFMKNnHvQ4AYmlmF-v4iCmrtetgOVivKk30FKcbp2YLd7pV.yS_oco2NX0KaIUr6IkqdrU12DLntCJlzZRgbiwPbeBEaozEh0SiWTzo35ic3_fxCN.JH7Ifx4drCfHNmicDnRnqH2lvbFg3LEqe7XaJ9kbxYSX1C_Lr7dDE3pdI47Y5OdDPkSvjK_RoQMDG8YTqdvQky1k.bXOyxDLVceMTPn2f1D8joDAWMEOKR7TA5Mr5sJj8HnYiNQw3dMfL85GQOI.PdtmSOAEKxeS.nf5zlDYDcZtAn2y3pBKKrVM3EsaoUBgV8gy30aITJ7uhAIMDUKTawsf6HUR.vzPAZ5l09xshFyzZ.iL2KN6CGlaHkPX2BJeFuAvdHCCkQfzG8UQdfdhrt6srAn0F.isE9LinMVcxjk_gX1iQ6En890DUqRq1QMsZdFRNoDtaPmlYuZyzIuPbP9BoKeUzcKrabe3xXH.Opr6PVcnpJXO1EjjhcsqEiC9dTSNBWTV28hLq4QrTzI9GtnaVV7h1gY.lMPOz0JlrLFiDe3KOjXDRBF9hN72JekIfNuG9Pqe8.sbStaCVPDJlO5QnMT8K8jKE9fe7M-6-c8yP711SfHIbsPGUzHQRu0X7ALLvsoFkc22LM5RF.KXIeel20-8t0dHGD.TMbINi8qq1WxwuHJ8xdW47netlfTR8n_uO18chNXvsqeiN.fhIlF4_xFhy.LI2a', 
                        comment = '', 
                        responded_at = '2022-01-04T00:00Z', )
                    ], 
                matching_entries = [
                    empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_matching.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        type = 'BUY', 
                        delivery_day_from = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_day_to = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        direction = 'GB_NL', 
                        posted_at = '2022-01-04T00:00Z', 
                        expires_at = '2022-01-04T00:00Z', 
                        matching_percentage = 0, )
                    ]
            )
        else :
            return SecondaryMarketDayAheadOrIntraDayNoticeboardEntry(
                notice_details = empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_details.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryDetails(
                    type = 'BUY', 
                    timescale = 'LONG_TERM', 
                    mtu_size = 'MTU_15_MINS', 
                    delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                    direction = 'GB_NL', 
                    expires_at = '2022-01-04T00:00Z', 
                    mtus = [
                        empire_platform_api_public_client.models.secondary_market_capacity_price_mtu.SecondaryMarketCapacityPriceMtu(
                            mtu = '2022-01-04T10:00Z', 
                            capacity = 56, 
                            price = 1.337, )
                        ], 
                    is_own = True, ),
                responses = [
                    empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse(
                        mtus = [
                            empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response_mtus_inner.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse_mtus_inner(
                                mtu = '2022-01-04T10:00Z', 
                                response_capacity = 56, 
                                response_price = 1.337, )
                            ], 
                        contact_name = '', 
                        phone_number = '+480728880015', 
                        email = '2@MDTMv2D2ylmgd10Z3UB6UkJSISSB512iz2DiJykO4IVP7YNsKQHh9BsaMPOiOuo3_QLOpkB.KIPOf2Flbsh1TpRS00PDvgoKGNXgxLHoPJE._eVrdJNcY9CLxYxBbcfSJXXZGSCF7dC-lSY-7ZlQJLW1_GNchKk5EBLDz1ctzsIY4oI.cl12VtuaSfjvmymTJfYkic17VJpcq1X6tjkH36lFYtIUw23vATP5cgpgctxW3q4fsZS5Uz-fvg2bA4.I-r1orbd3s4Kdu4Q19mfvL0A7Rpn3Av26g7OJWsQ0WBkWv3CuuRrMkJf5gzLvv2wY.NPqhvoybcy8QU.0_1u6BhIo-27B5JIFoxlv9-BJxhRRelW6lINX6.1Elv8Z4qYvYNwb3t4awGG-6yh0-gMEzQ8uhi90kNEaHx.5LWBoOt62fDnfouEM59JJWYHa1Ya1DpwFCTpIA0Gnqa9PQ0lvjCR3UYpt1vrS1p.R1OzxrQfgrgcyvfHmHL7bSaRv9kZ_K.NGkIi19s7KrTBx8qCkWG3nkJgXYUf-2g1bLoF4Q2SDvsQvki_Gv.3xSglBiD_kTqWft7LgtQq8DkTxH9-GEgnhdskTUa-JGB99tBTH1m8LyVjqKCRWp6XS1rwkzrnn.h0XoK7cYVKPWx4kXAhG_GEdV9fi1LUY2eBXIK-aaNx-IAoUxtYKQpsS2HM0cvxv.88aJmQRbOi5pM9K4SWNKj0UeVyhnBjVWguY2vNQIw3D_aRMF2Tm7SelZBdyPOLRs2IImu0zJ-sEvqrLoPmgi.JrQNmT_4QLVs0oSHjB6pC-1mwGXNIZ-mK8w9K1xfp9OikxJ6eiOUAchnVGrwqvIGWHJ7Z1.eTeQr7h2GhDiufc8pTDOUcgYQwyEct13aGy9ShDDH49uy_cuS1qDT5br69Zb9J7ztaciXoL3UMxQsS4RhgPVNkMuBNIrWv_v.6kENTnbd0jYevK4Igno2LdfSDI1Cs6huybGb1zEpVJcz_sYPOWoI5540Y2OLcYufJVmh2PNuin04QumvvjetJ2wYXn.2W6zwIrDKlbs9CPExuzXJjOmov9hu5QjJ_xMDMiy-rwLYYugfVA0tbOL0.zdgU9sGpVxk.V0XsgBCaMb6w.WmQk2AHCmB9lVwewmjj04um-gQsMcYoZx6RzkDL1MAzcQRnYq9jshsHLjup_Xq1.S5JIFlA8s7VLbfJ8CdU1--K_bbEzgXW.tGc11HJjfPh9aPBMPn9vOOHdKkQ6_InnGXC1663IOeomDvz9sa4XpvFxFUjA2Vr.PYqBpPgKYJXJXx50oGq47BDC1bkGeAny7jvr.nVoFMKNnHvQ4AYmlmF-v4iCmrtetgOVivKk30FKcbp2YLd7pV.yS_oco2NX0KaIUr6IkqdrU12DLntCJlzZRgbiwPbeBEaozEh0SiWTzo35ic3_fxCN.JH7Ifx4drCfHNmicDnRnqH2lvbFg3LEqe7XaJ9kbxYSX1C_Lr7dDE3pdI47Y5OdDPkSvjK_RoQMDG8YTqdvQky1k.bXOyxDLVceMTPn2f1D8joDAWMEOKR7TA5Mr5sJj8HnYiNQw3dMfL85GQOI.PdtmSOAEKxeS.nf5zlDYDcZtAn2y3pBKKrVM3EsaoUBgV8gy30aITJ7uhAIMDUKTawsf6HUR.vzPAZ5l09xshFyzZ.iL2KN6CGlaHkPX2BJeFuAvdHCCkQfzG8UQdfdhrt6srAn0F.isE9LinMVcxjk_gX1iQ6En890DUqRq1QMsZdFRNoDtaPmlYuZyzIuPbP9BoKeUzcKrabe3xXH.Opr6PVcnpJXO1EjjhcsqEiC9dTSNBWTV28hLq4QrTzI9GtnaVV7h1gY.lMPOz0JlrLFiDe3KOjXDRBF9hN72JekIfNuG9Pqe8.sbStaCVPDJlO5QnMT8K8jKE9fe7M-6-c8yP711SfHIbsPGUzHQRu0X7ALLvsoFkc22LM5RF.KXIeel20-8t0dHGD.TMbINi8qq1WxwuHJ8xdW47netlfTR8n_uO18chNXvsqeiN.fhIlF4_xFhy.LI2a', 
                        comment = '', 
                        responded_at = '2022-01-04T00:00Z', )
                    ],
                matching_entries = [
                    empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_matching.SecondaryMarketDayAheadOrIntraDayNoticeboardEntryMatching(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        type = 'BUY', 
                        delivery_day_from = 'Tue Jan 04 00:00:00 UTC 2022', 
                        delivery_day_to = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        direction = 'GB_NL', 
                        posted_at = '2022-01-04T00:00Z', 
                        expires_at = '2022-01-04T00:00Z', 
                        matching_percentage = 0, )
                    ],
        )
        """

    def testSecondaryMarketDayAheadOrIntraDayNoticeboardEntry(self):
        """Test SecondaryMarketDayAheadOrIntraDayNoticeboardEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field

class AuctionProcessStepsAbsolute(BaseModel):
    """
    Deadlines of each phase of the auction
    """
    preliminary_spec_publish: datetime = Field(..., alias="preliminarySpecPublish", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    returns_window_close: Optional[datetime] = Field(None, alias="returnsWindowClose", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    final_spec_publish: datetime = Field(..., alias="finalSpecPublish", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    bidding_open: datetime = Field(..., alias="biddingOpen", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    show_bids_for_open_auctions: Optional[datetime] = Field(None, alias="showBidsForOpenAuctions", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    bidding_close: datetime = Field(..., alias="biddingClose", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    provisional_results_publish: datetime = Field(..., alias="provisionalResultsPublish", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    final_results_publish: datetime = Field(..., alias="finalResultsPublish", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["preliminarySpecPublish", "returnsWindowClose", "finalSpecPublish", "biddingOpen", "showBidsForOpenAuctions", "biddingClose", "provisionalResultsPublish", "finalResultsPublish"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuctionProcessStepsAbsolute:
        """Create an instance of AuctionProcessStepsAbsolute from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuctionProcessStepsAbsolute:
        """Create an instance of AuctionProcessStepsAbsolute from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AuctionProcessStepsAbsolute.parse_obj(obj)

        _obj = AuctionProcessStepsAbsolute.parse_obj({
            "preliminary_spec_publish": obj.get("preliminarySpecPublish"),
            "returns_window_close": obj.get("returnsWindowClose"),
            "final_spec_publish": obj.get("finalSpecPublish"),
            "bidding_open": obj.get("biddingOpen"),
            "show_bids_for_open_auctions": obj.get("showBidsForOpenAuctions"),
            "bidding_close": obj.get("biddingClose"),
            "provisional_results_publish": obj.get("provisionalResultsPublish"),
            "final_results_publish": obj.get("finalResultsPublish")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Union
from pydantic import BaseModel, Field, confloat, conint, conlist
from empire_platform_api_public_client.models.participant_dashboard_finance_overview_invoice import ParticipantDashboardFinanceOverviewInvoice

class ParticipantDashboardFinanceOverviewData(BaseModel):
    """
    ParticipantDashboardFinanceOverviewData
    """
    credit_cover: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="creditCover", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    credit_utilization: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="creditUtilization", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    credit_limit: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="creditLimit", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    invoices: conlist(ParticipantDashboardFinanceOverviewInvoice) = Field(...)
    __properties = ["creditCover", "creditUtilization", "creditLimit", "invoices"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardFinanceOverviewData:
        """Create an instance of ParticipantDashboardFinanceOverviewData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in invoices (list)
        _items = []
        if self.invoices:
            for _item in self.invoices:
                if _item:
                    _items.append(_item.to_dict())
            _dict['invoices'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardFinanceOverviewData:
        """Create an instance of ParticipantDashboardFinanceOverviewData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardFinanceOverviewData.parse_obj(obj)

        _obj = ParticipantDashboardFinanceOverviewData.parse_obj({
            "credit_cover": obj.get("creditCover"),
            "credit_utilization": obj.get("creditUtilization"),
            "credit_limit": obj.get("creditLimit"),
            "invoices": [ParticipantDashboardFinanceOverviewInvoice.from_dict(_item) for _item in obj.get("invoices")] if obj.get("invoices") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import List, Union
from pydantic import BaseModel, Field, confloat, conint, conlist
from empire_platform_api_public_client.models.settlement_item import SettlementItem

class Settlement(BaseModel):
    """
    Settlement
    """
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    total_amount: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="totalAmount", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    values: conlist(SettlementItem) = Field(...)
    __properties = ["deliveryDay", "totalAmount", "values"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Settlement:
        """Create an instance of Settlement from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in values (list)
        _items = []
        if self.values:
            for _item in self.values:
                if _item:
                    _items.append(_item.to_dict())
            _dict['values'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Settlement:
        """Create an instance of Settlement from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Settlement.parse_obj(obj)

        _obj = Settlement.parse_obj({
            "delivery_day": obj.get("deliveryDay"),
            "total_amount": obj.get("totalAmount"),
            "values": [SettlementItem.from_dict(_item) for _item in obj.get("values")] if obj.get("values") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import date

from pydantic import Field, StrictStr, conint, conlist

from typing import Optional

from empire_platform_api_public_client.models.create_organisation_document_request import CreateOrganisationDocumentRequest
from empire_platform_api_public_client.models.created_organisation_document import CreatedOrganisationDocument
from empire_platform_api_public_client.models.organisation_document_batch import OrganisationDocumentBatch
from empire_platform_api_public_client.models.organisation_document_file_type import OrganisationDocumentFileType
from empire_platform_api_public_client.models.organisation_document_options import OrganisationDocumentOptions
from empire_platform_api_public_client.models.organisation_document_sort_by import OrganisationDocumentSortBy

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class OrganisationDocumentApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_organisation_document(self, x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], create_organisation_document_request : CreateOrganisationDocumentRequest, **kwargs) -> CreatedOrganisationDocument:  # noqa: E501
        """create_organisation_document  # noqa: E501

        Create new Organisation Document for a given Organisation  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `CREATE_ORGANISATION_DOCUMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_organisation_document(x_organisation_id, create_organisation_document_request, async_req=True)
        >>> result = thread.get()

        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param create_organisation_document_request: (required)
        :type create_organisation_document_request: CreateOrganisationDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreatedOrganisationDocument
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the create_organisation_document_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.create_organisation_document_with_http_info(x_organisation_id, create_organisation_document_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_organisation_document_with_http_info(self, x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], create_organisation_document_request : CreateOrganisationDocumentRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """create_organisation_document  # noqa: E501

        Create new Organisation Document for a given Organisation  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `CREATE_ORGANISATION_DOCUMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_organisation_document_with_http_info(x_organisation_id, create_organisation_document_request, async_req=True)
        >>> result = thread.get()

        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param create_organisation_document_request: (required)
        :type create_organisation_document_request: CreateOrganisationDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreatedOrganisationDocument, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'x_organisation_id',
            'create_organisation_document_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_organisation_document" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_organisation_id']:
            _header_params['X-Organisation-Id'] = _params['x_organisation_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_organisation_document_request'] is not None:
            _body_params = _params['create_organisation_document_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '201': "CreatedOrganisationDocument",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/organisation-documents', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_organisation_document(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> None:  # noqa: E501
        """delete_organisation_document  # noqa: E501

        Delete an existing Organisation Document by its identifier  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `DELETE_ORGANISATION_DOCUMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_organisation_document(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the delete_organisation_document_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.delete_organisation_document_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_organisation_document_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """delete_organisation_document  # noqa: E501

        Delete an existing Organisation Document by its identifier  ---  __Requires Permission:__ (at least one)   * `MANAGE_OWN_ORGANISATION_DOCUMENTS`   * `MANAGE_ANY_ORGANISATION_DOCUMENTS`  __Generates Audit Log Entry:__ `DELETE_ORGANISATION_DOCUMENT`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_organisation_document_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_organisation_document" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/v1/organisation-documents/{id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_organisation_document_options(self, x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], **kwargs) -> OrganisationDocumentOptions:  # noqa: E501
        """get_organisation_document_options  # noqa: E501

        Fetch options for Organisation Documents for a given Organisation  Implementation notes:   - `fileTypes` - the uploaded files' MIME Types grouped to the defined categories   - `organisations` - Organisation that have uploaded files     - `users` - Users in the given Organisation that have uploaded files  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_ORGANISATION_DOCUMENTS`   * `VIEW_ANY_ORGANISATION_DOCUMENTS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_organisation_document_options(x_organisation_id, async_req=True)
        >>> result = thread.get()

        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrganisationDocumentOptions
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_organisation_document_options_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_organisation_document_options_with_http_info(x_organisation_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_organisation_document_options_with_http_info(self, x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_organisation_document_options  # noqa: E501

        Fetch options for Organisation Documents for a given Organisation  Implementation notes:   - `fileTypes` - the uploaded files' MIME Types grouped to the defined categories   - `organisations` - Organisation that have uploaded files     - `users` - Users in the given Organisation that have uploaded files  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_ORGANISATION_DOCUMENTS`   * `VIEW_ANY_ORGANISATION_DOCUMENTS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_organisation_document_options_with_http_info(x_organisation_id, async_req=True)
        >>> result = thread.get()

        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrganisationDocumentOptions, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'x_organisation_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organisation_document_options" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_organisation_id']:
            _header_params['X-Organisation-Id'] = _params['x_organisation_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "OrganisationDocumentOptions",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/organisation-documents/options', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_organisation_documents(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[OrganisationDocumentSortBy, Field(..., description="Sort list by given attribute and direction")], x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], query : Annotated[Optional[StrictStr], Field(description="Free text search in fileName and description")] = None, file_types : Optional[conlist(OrganisationDocumentFileType)] = None, uploaded_at_from : Optional[date] = None, uploaded_at_to : Optional[date] = None, uploaded_by_org_id : Optional[StrictStr] = None, uploaded_by_user_ids : Optional[conlist(StrictStr)] = None, **kwargs) -> OrganisationDocumentBatch:  # noqa: E501
        """get_organisation_documents  # noqa: E501

        Fetch a paginated, filterable list of Organisation Documents for a given Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_ORGANISATION_DOCUMENTS`   * `VIEW_ANY_ORGANISATION_DOCUMENTS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_organisation_documents(limit, offset, sort_by, x_organisation_id, query, file_types, uploaded_at_from, uploaded_at_to, uploaded_by_org_id, uploaded_by_user_ids, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: OrganisationDocumentSortBy
        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param query: Free text search in fileName and description
        :type query: str
        :param file_types:
        :type file_types: List[OrganisationDocumentFileType]
        :param uploaded_at_from:
        :type uploaded_at_from: date
        :param uploaded_at_to:
        :type uploaded_at_to: date
        :param uploaded_by_org_id:
        :type uploaded_by_org_id: str
        :param uploaded_by_user_ids:
        :type uploaded_by_user_ids: List[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OrganisationDocumentBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_organisation_documents_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_organisation_documents_with_http_info(limit, offset, sort_by, x_organisation_id, query, file_types, uploaded_at_from, uploaded_at_to, uploaded_by_org_id, uploaded_by_user_ids, **kwargs)  # noqa: E501

    @validate_arguments
    def get_organisation_documents_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[OrganisationDocumentSortBy, Field(..., description="Sort list by given attribute and direction")], x_organisation_id : Annotated[StrictStr, Field(..., description="Internal ID of an Organisation")], query : Annotated[Optional[StrictStr], Field(description="Free text search in fileName and description")] = None, file_types : Optional[conlist(OrganisationDocumentFileType)] = None, uploaded_at_from : Optional[date] = None, uploaded_at_to : Optional[date] = None, uploaded_by_org_id : Optional[StrictStr] = None, uploaded_by_user_ids : Optional[conlist(StrictStr)] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_organisation_documents  # noqa: E501

        Fetch a paginated, filterable list of Organisation Documents for a given Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_ORGANISATION_DOCUMENTS`   * `VIEW_ANY_ORGANISATION_DOCUMENTS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_organisation_documents_with_http_info(limit, offset, sort_by, x_organisation_id, query, file_types, uploaded_at_from, uploaded_at_to, uploaded_by_org_id, uploaded_by_user_ids, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: OrganisationDocumentSortBy
        :param x_organisation_id: Internal ID of an Organisation (required)
        :type x_organisation_id: str
        :param query: Free text search in fileName and description
        :type query: str
        :param file_types:
        :type file_types: List[OrganisationDocumentFileType]
        :param uploaded_at_from:
        :type uploaded_at_from: date
        :param uploaded_at_to:
        :type uploaded_at_to: date
        :param uploaded_by_org_id:
        :type uploaded_by_org_id: str
        :param uploaded_by_user_ids:
        :type uploaded_by_user_ids: List[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OrganisationDocumentBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'x_organisation_id',
            'query',
            'file_types',
            'uploaded_at_from',
            'uploaded_at_to',
            'uploaded_by_org_id',
            'uploaded_by_user_ids'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organisation_documents" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('query', _params['query']))

        if _params.get('file_types') is not None:  # noqa: E501
            _query_params.append(('fileTypes', _params['file_types']))
            _collection_formats['fileTypes'] = 'multi'

        if _params.get('uploaded_at_from') is not None:  # noqa: E501
            if isinstance(_params['uploaded_at_from'], datetime):
                _query_params.append(('uploadedAtFrom', _params['uploaded_at_from'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('uploadedAtFrom', _params['uploaded_at_from']))

        if _params.get('uploaded_at_to') is not None:  # noqa: E501
            if isinstance(_params['uploaded_at_to'], datetime):
                _query_params.append(('uploadedAtTo', _params['uploaded_at_to'].strftime(self.api_client.configuration.date_format)))
            else:
                _query_params.append(('uploadedAtTo', _params['uploaded_at_to']))

        if _params.get('uploaded_by_org_id') is not None:  # noqa: E501
            _query_params.append(('uploadedByOrgId', _params['uploaded_by_org_id']))

        if _params.get('uploaded_by_user_ids') is not None:  # noqa: E501
            _query_params.append(('uploadedByUserIds', _params['uploaded_by_user_ids']))
            _collection_formats['uploadedByUserIds'] = 'multi'

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_organisation_id']:
            _header_params['X-Organisation-Id'] = _params['x_organisation_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "OrganisationDocumentBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/organisation-documents', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date

from pydantic import BaseModel, Field

class DatePeriod(BaseModel):
    """
    Period of calendar days, interpreted in **System Time**  - both ends of the period are inclusive - should be interpreted on the timeline as from _start date 00:00_ until _end date 24:00_ 
    """
    start: date = Field(..., description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    end: date = Field(..., description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    __properties = ["start", "end"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DatePeriod:
        """Create an instance of DatePeriod from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DatePeriod:
        """Create an instance of DatePeriod from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DatePeriod.parse_obj(obj)

        _obj = DatePeriod.parse_obj({
            "start": obj.get("start"),
            "end": obj.get("end")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Union
from pydantic import BaseModel, Field, StrictBool, confloat, conint
from empire_platform_api_public_client.models.auction_bidding_mode import AuctionBiddingMode

class AuctionBiddingConfiguration(BaseModel):
    """
    AuctionBiddingConfiguration
    """
    mode: AuctionBiddingMode = Field(...)
    pre_bidding_allowed: StrictBool = Field(..., alias="preBiddingAllowed", description="Specify if pre-bidding is allowed or not.")
    max_bids_per_participants: conint(strict=True, ge=0) = Field(..., alias="maxBidsPerParticipants", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    min_bid_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="minBidPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["mode", "preBiddingAllowed", "maxBidsPerParticipants", "minBidPrice"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuctionBiddingConfiguration:
        """Create an instance of AuctionBiddingConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuctionBiddingConfiguration:
        """Create an instance of AuctionBiddingConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AuctionBiddingConfiguration.parse_obj(obj)

        _obj = AuctionBiddingConfiguration.parse_obj({
            "mode": obj.get("mode"),
            "pre_bidding_allowed": obj.get("preBiddingAllowed"),
            "max_bids_per_participants": obj.get("maxBidsPerParticipants"),
            "min_bid_price": obj.get("minBidPrice")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data import ParticipantDashboardInterconnectorCapacityGraphData  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestParticipantDashboardInterconnectorCapacityGraphData(unittest.TestCase):
    """ParticipantDashboardInterconnectorCapacityGraphData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ParticipantDashboardInterconnectorCapacityGraphData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParticipantDashboardInterconnectorCapacityGraphData`
        """
        model = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data.ParticipantDashboardInterconnectorCapacityGraphData()  # noqa: E501
        if include_optional :
            return ParticipantDashboardInterconnectorCapacityGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_values_inner(
                                direction = 'GB_NL', 
                                ntc = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_nettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), )
                    ]
            )
        else :
            return ParticipantDashboardInterconnectorCapacityGraphData(
                mtus = [
                    empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner(
                        mtu = '2022-01-04T10:00Z', 
                        values = [
                            empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_values_inner.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_values_inner(
                                direction = 'GB_NL', 
                                ntc = 56, )
                            ], 
                        netted_nominations = empire_platform_api_public_client.models.participant_dashboard_interconnector_capacity_graph_data_mtus_inner_netted_nominations.ParticipantDashboardInterconnectorCapacityGraphData_mtus_inner_nettedNominations(
                            direction = 'GB_NL', 
                            flow = 56, ), )
                    ],
        )
        """

    def testParticipantDashboardInterconnectorCapacityGraphData(self):
        """Test ParticipantDashboardInterconnectorCapacityGraphData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictInt, StrictStr, confloat, conint
from empire_platform_api_public_client.models.return_auction import ReturnAuction
from empire_platform_api_public_client.models.secondary_market_return_request_status import SecondaryMarketReturnRequestStatus
from empire_platform_api_public_client.models.source_auction_display_data import SourceAuctionDisplayData

class SecondaryMarketReturnRequest(BaseModel):
    """
    SecondaryMarketReturnRequest
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    source_auction: SourceAuctionDisplayData = Field(..., alias="sourceAuction")
    return_auction: ReturnAuction = Field(..., alias="returnAuction")
    returned_capacity: StrictInt = Field(..., alias="returnedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    successfully_allocated_capacity: Optional[StrictInt] = Field(None, alias="successfullyAllocatedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    price: Optional[Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)]] = Field(None, description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    status: SecondaryMarketReturnRequestStatus = Field(...)
    __properties = ["id", "sourceAuction", "returnAuction", "returnedCapacity", "successfullyAllocatedCapacity", "price", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SecondaryMarketReturnRequest:
        """Create an instance of SecondaryMarketReturnRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of source_auction
        if self.source_auction:
            _dict['sourceAuction'] = self.source_auction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of return_auction
        if self.return_auction:
            _dict['returnAuction'] = self.return_auction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SecondaryMarketReturnRequest:
        """Create an instance of SecondaryMarketReturnRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SecondaryMarketReturnRequest.parse_obj(obj)

        _obj = SecondaryMarketReturnRequest.parse_obj({
            "id": obj.get("id"),
            "source_auction": SourceAuctionDisplayData.from_dict(obj.get("sourceAuction")) if obj.get("sourceAuction") is not None else None,
            "return_auction": ReturnAuction.from_dict(obj.get("returnAuction")) if obj.get("returnAuction") is not None else None,
            "returned_capacity": obj.get("returnedCapacity"),
            "successfully_allocated_capacity": obj.get("successfullyAllocatedCapacity"),
            "price": obj.get("price"),
            "status": obj.get("status")
        })
        return _obj




# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api)   # noqa: E501

    The version of the OpenAPI document: 1.0.5
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictInt, confloat, conint, conlist
from empire_platform_api_public_client.models.auction_result_congestion_rent import AuctionResultCongestionRent
from empire_platform_api_public_client.models.day_ahead_or_intra_day_auction_mtu_results_bids_inner import DayAheadOrIntraDayAuctionMtuResultsBidsInner
from empire_platform_api_public_client.models.long_term_auction_results_allocated_capacity_inner import LongTermAuctionResultsAllocatedCapacityInner

class LongTermAuctionResults(BaseModel):
    """
    LongTermAuctionResults
    """
    congestion_rent: Optional[AuctionResultCongestionRent] = Field(None, alias="congestionRent")
    bids: conlist(DayAheadOrIntraDayAuctionMtuResultsBidsInner) = Field(...)
    total_requested_capacity: StrictInt = Field(..., alias="totalRequestedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    total_allocated_capacity: StrictInt = Field(..., alias="totalAllocatedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    allocated_capacity: conlist(LongTermAuctionResultsAllocatedCapacityInner) = Field(..., alias="allocatedCapacity")
    marginal_price: Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)] = Field(..., alias="marginalPrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    reserve_price: Optional[Union[confloat(multiple_of=0.01, strict=True), conint(strict=True)]] = Field(None, alias="reservePrice", description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places")
    __properties = ["congestionRent", "bids", "totalRequestedCapacity", "totalAllocatedCapacity", "allocatedCapacity", "marginalPrice", "reservePrice"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LongTermAuctionResults:
        """Create an instance of LongTermAuctionResults from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of congestion_rent
        if self.congestion_rent:
            _dict['congestionRent'] = self.congestion_rent.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in bids (list)
        _items = []
        if self.bids:
            for _item in self.bids:
                if _item:
                    _items.append(_item.to_dict())
            _dict['bids'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in allocated_capacity (list)
        _items = []
        if self.allocated_capacity:
            for _item in self.allocated_capacity:
                if _item:
                    _items.append(_item.to_dict())
            _dict['allocatedCapacity'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LongTermAuctionResults:
        """Create an instance of LongTermAuctionResults from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return LongTermAuctionResults.parse_obj(obj)

        _obj = LongTermAuctionResults.parse_obj({
            "congestion_rent": AuctionResultCongestionRent.from_dict(obj.get("congestionRent")) if obj.get("congestionRent") is not None else None,
            "bids": [DayAheadOrIntraDayAuctionMtuResultsBidsInner.from_dict(_item) for _item in obj.get("bids")] if obj.get("bids") is not None else None,
            "total_requested_capacity": obj.get("totalRequestedCapacity"),
            "total_allocated_capacity": obj.get("totalAllocatedCapacity"),
            "allocated_capacity": [LongTermAuctionResultsAllocatedCapacityInner.from_dict(_item) for _item in obj.get("allocatedCapacity")] if obj.get("allocatedCapacity") is not None else None,
            "marginal_price": obj.get("marginalPrice"),
            "reserve_price": obj.get("reservePrice")
        })
        return _obj

